@@ -44,7 +44,7 @@ compact.ff <- function(x, use.na=TRUE,...){
 #' @export
 #' @export compact.ffdf
 compact.ffdf <- function(x, use.na=TRUE, ...){
-   ret <- lapply(physical(x), compact, use.na=use.na, ...)
+   ret <- lapply(bit::physical(x), compact, use.na=use.na, ...)
    res <- do.call(ffdf, ret)
    close(x)
    res
